package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.36.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.36.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,`*``!````V!4``#0```"4C@````(`!30`(``'
M`"@`&P`:``8````T````-````#0```#@````X`````0````$`````P```!0!
M```4`0``%`$``!<````7````!`````$````!````````````````````Z(@`
M`.B(```%```````!``$```#HB```Z(@!`.B(`0"<`@``'`<```8```````$`
M`@```/2(``#TB`$`](@!`/````#P````!@````0````$````+`$``"P!```L
M`0``2````$@````$````!````%#E=&3L@@``[((``.R"``#L````[`````0`
M```$````+W5S<B]L:6)E>&5C+VQD+F5L9E]S;P``!P````0````!````3F5T
M0E-$````Z:0U!`````0````#````4&%8```````'````!0````4```!.971"
M4T0``&5A<FT`````80```&8``````````````#`````.```````````````W
M````#P```#\`````````+P`````````#````30```%X`````````'P```$P`
M```&````'0```!0`````````0@````````!:`````````!<````[````50``
M`%\`````````8@```&0````N````$@````````!$````%0```%D```!&````
M`````$D```!%````-````%@````E````*@`````````'````3@`````````,
M````"@```&4```!7````2P```"````!#````8P````````!<`````````!@`
M```M````0````````````````````!$````R``````````D```!=````3P``
M`````````````````",````X`````````%`````%````1P```!L````Z````
M`````````````````````$H`````````.0```%(```!@`````````&$`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````3````````````````````
M````````````````````````````````(@```"$`````````*0`````````G
M````*````"P```````````````T````+````'````!H````9````````````
M```0`````````#,````Q````-@```!X`````````````````````````````
M``0```````````````````!!````)````````````````````!8`````````
M/@```"L````(```````````````]`````````%0````F`````````#P`````
M`````````%$`````````2````````````````````%,```!6````-0```%L`
M``````````````````````````````````#8%0````````,`"P``````\(@!
M```````#`!$`EP``````````````$@````P``````````````!(````4````
M```````````2````6@,``!@?```(````$@`+`!P``````````````"(````K
M```````````````2````,0``````````````$@```&L#``"$BP$``````!``
M%0`X```````````````2````/@``````````````$@```'D#``#T)0``(```
M`!(`"P!%```````````````2````,`,`````````````$@```)0#``"$,0``
M:````!(`"P"(```````````````2````J`,```20`0``````$``5`$T`````
M`````````!(```"@`P``A(L!```````0`!0`70``````````````$@```&P`
M`````````````!(```!R```````````````2````>0``````````````$@``
M`(,``````````````!(```"-```````````````2````IP,```20`0``````
M$``5`)8``````````````!(````H`P`````````````2````G```````````
M````$@```*,``````````````!(```"Q```````````````2````P@``````
M````````$0```,\``````````````!(```"S`P``H"$``"@````2``L`P`,`
M`,@A``!4`0``$@`+`,P#```()P``N`<``!(`"P#K`@`````````````2````
MW0``````````````%@```/```````````````!(```!"`P`````````````2
M````^P``````````````$@````0!````D`$`!````!$`%0`,`0``````````
M```2````'@,`````````````$@```!@!`````````````!(````?`0``````
M```````2````V0,``%0^``#L````$@`+`#(!`````````````!$```!$`0``
M```````````2````5`$`````````````$@```&(!`````````````!(```!G
M`0`````````````2````Y`,``("+`0`$````$0`4`'8!`````````````!(`
M``""`0`````````````2````EP$`````````````$@```*(!````````````
M`!(```!5`P``!)`!```````0`!4`R@(`````````````$@```+4!````````
M`````!(````G!```V!4````````2``L`PP$`````````````$@```,L!````
M`````````"(```#C`0`````````````2````[P$`````````````$@```.X#
M```$D`$``````!``%0#V`P``'",``#`"```2``L`]0$`````````````(@``
M``L"`````````````!(````6`@`````````````2`````P0``$`_``!X`0``
M$@`+`"<"`````````````!(````-!```A(L!```````0`!4`&00``#@>``!H
M````$@`+`"$$``"400``@`(``!(`"P`N`@`````````````2````)@0``-@5
M````````$@`+`#4"`````````````!(````N!```(!\``(`"```2``L`.P0`
M`!0F``#T````$@`+`$T$``!,)0``J````!(`"P!,`@`````````````2````
MV0(`````````````$@```%T"`````````````!(```!F`@`````````````2
M````;`(`````````````$@```!$#`````````````!(```!Q`@``````````
M```2````!`,``,2+`0`$````$0`5`'D"`````````````!(````W`P``````
M```````2````@`(`````````````$@```%L$``#T/0``8````!(`"P"'`@``
M```````````2````E@(`````````````$0```/D"``!$BP$`!````!$`%`!D
M!```P"X``,0"```2``L`*P$`````````````$@```)L"`````````````!(`
M``!)`P`````````````2`````&QI8G!E<FPN<V\`<F5A;&QO8P!M96UM;W9E
M`%]?8WAA7V9I;F%L:7IE`')M9&ER`'-T<G-T<@!C;&]S90!S=')C:'(`<W1R
M;F-M<`!B;V]T7T1Y;F%,;V%D97(`<&5R;%]C;VYS=')U8W0`86)O<G0`=6YL
M:6YK`%]?;'-T870U,`!P97)L7V9R964`7U]S=&%T-3``7V5X:70`;65M8W!Y
M`'!E<FQ?9&5S=')U8W0`7U]S=&%C:U]C:&M?9F%I;`!03%]D;U]U;F1U;7``
M4&5R;%]S=E]S971P=@!03%]C=7)R96YT7V-O;G1E>'0`<&5R;%]A;&QO8P!C
M;&]S961I<@!E;G9I<F]N`%]?;W!E;F1I<C,P`&UE;7-E=`!097)L7W-A9F5S
M>7-M86QL;V,`7U]S=&%C:U]C:&M?9W5A<F0`4&5R;%]G=E]F971C:'!V`%]?
M<W!R:6YT9E]C:&L`<F5A9`!097)L7W-Y<U]I;FET,P!097)L7V=E=%]S=@!0
M97)L7V-R;V%K7VYO8V]N=&5X=`!097)L7VYE=UA3`%!E<FQ?871F;W)K7W5N
M;&]C:P!097)L7W-Y<U]T97)M`%]?97)R;F\`7U]D97)E9VES=&5R7V9R86UE
M7VEN9F\`4&5R;%]M9U]S970`;6MD:7(`7U]R96=I<W1E<E]F<F%M95]I;F9O
M`'!E<FQ?<&%R<V4`4&5R;%]N97=84U]F;&%G<P!A8V-E<W,`9V5T<&ED`%!E
M<FQ?8W)O86M?;65M;W)Y7W=R87``4&5R;%]A=&9O<FM?;&]C:P!P97)L7W)U
M;@!L<V5E:P!O<&5N`'-P<FEN=&8`9V5T=6ED`'-T<FQE;@!?7W1L<U]G971?
M861D<@!?7W-&`'-T<F-M<`!L:6)M+G-O+C``;&EB8W)Y<'0N<V\N,0!L:6)P
M=&AR96%D+G-O+C$`<'1H<F5A9%]A=&9O<FL`<W1R9'5P`&QI8F,N<V\N,3(`
M7U]S=')N8W!Y7V-H:P!?7W!R;V=N86UE`%]?<'-?<W1R:6YG<P!?7V=E='!W
M=6ED-3``7U]S>7-C86QL`&9P<FEN=&8`871E>&ET`%]L:6)C7VEN:70`<W1R
M=&]K`%]?<F5A9&1I<C,P`%]E;F0`<&%R7V-U<G)E;G1?97AE8P!?7V)S<U]S
M=&%R=%]?`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A<E]C;&5A;G5P
M`%]E9&%T80!?7V)S<U]E;F1?7P!P87)?8F%S96YA;64`<&%R7V1I<FYA;64`
M<&%R7VUK=&UP9&ER`'-H85]U<&1A=&4`;7E?<&%R7W!L`%]?96YD7U\`<&%R
M7VEN:71?96YV`'-H85]F:6YA;`!?7V)S<U]S=&%R=`!X<U]I;FET`&UA:6X`
M7U]S=&%R=`!P87)?9FEN9'!R;V<`<&%R7W-E='5P7VQI8G!A=&@`<&%R7V5N
M=E]C;&5A;@!S:&%?:6YI=`!84U]);G1E<FYA;'-?4$%27T)/3U0`+W5S<B]P
M:V<O;&EB+W!E<FPU+S4N,S8N,"]E87)M+6YE=&)S9"UT:')E860M;75L=&DO
M0T]213HO=7-R+W!K9R]L:6(``.B(`0`7````[(@!`!<```#LB@$`%P```/2*
M`0`7````_(H!`!<````,BP$`%P```!"+`0`7````&(L!`!<````<BP$`%P``
M`"R+`0`7````-(L!`!<````\BP$`%P```$"+`0`7````1(L!`!<```!(BP$`
M%P```%"+`0`7````5(L!`!<```!<BP$`%P```&"+`0`7````9(L!`!<```!H
MBP$`%P```&R+`0`7````=(L!`!<```!XBP$`%P```("+`0`7````\(H!`!4'
M``#XB@$`%1,```"+`0`5(0``!(L!`!$G```(BP$`$B<``!2+`0`5,0``((L!
M`!4Z```DBP$`%4```"B+`0`510``,(L!`!53```XBP$`%6```/")`0`6`P``
M](D!`!8$``#XB0$`%@4``/R)`0`6!P```(H!`!8(```$B@$`%@D```B*`0`6
M"P``#(H!`!8,```0B@$`%@X``!2*`0`6#P``&(H!`!81```<B@$`%A4``""*
M`0`6%@``)(H!`!87```HB@$`%A@``"R*`0`6&0``,(H!`!8:```TB@$`%AP`
M`#B*`0`6'0``/(H!`!8>``!`B@$`%A\``$2*`0`6(```2(H!`!8B``!,B@$`
M%B8``%"*`0`6*```5(H!`!8I``!8B@$`%BH``%R*`0`6+```8(H!`!8M``!D
MB@$`%BX``&B*`0`6+P``;(H!`!8R``!PB@$`%C,``'2*`0`6-```>(H!`!8U
M``!\B@$`%C<``("*`0`6.```A(H!`!8Y``"(B@$`%CP``(R*`0`6/0``D(H!
M`!8_``"4B@$`%D```)B*`0`600``G(H!`!9"``"@B@$`%D4``*2*`0`61@``
MJ(H!`!9'``"LB@$`%DD``+"*`0`630``M(H!`!9/``"XB@$`%E0``+R*`0`6
M50``P(H!`!96``#$B@$`%E<``,B*`0`66```S(H!`!99``#0B@$`%EL``-2*
M`0`67```V(H!`!9=``#<B@$`%E\``."*`0`68P``Y(H!`!9D``#HB@$`%F4`
M``3@+>4$X)_E#N"/X`CPON4$=P$``,:/XA?*C.($][SE`,:/XA?*C.+\]KSE
M`,:/XA?*C.+T]KSE`,:/XA?*C.+L]KSE`,:/XA?*C.+D]KSE`,:/XA?*C.+<
M]KSE`,:/XA?*C.+4]KSE`,:/XA?*C.+,]KSE`,:/XA?*C.+$]KSE`,:/XA?*
MC.*\]KSE`,:/XA?*C.*T]KSE`,:/XA?*C.*L]KSE`,:/XA?*C.*D]KSE`,:/
MXA?*C.*<]KSE`,:/XA?*C.*4]KSE`,:/XA?*C.*,]KSE`,:/XA?*C.*$]KSE
M`,:/XA?*C.)\]KSE`,:/XA?*C.)T]KSE`,:/XA?*C.)L]KSE`,:/XA?*C.)D
M]KSE`,:/XA?*C.)<]KSE`,:/XA?*C.)4]KSE`,:/XA?*C.),]KSE`,:/XA?*
MC.)$]KSE`,:/XA?*C.(\]KSE`,:/XA?*C.(T]KSE`,:/XA?*C.(L]KSE`,:/
MXA?*C.(D]KSE`,:/XA?*C.(<]KSE`,:/XA?*C.(4]KSE`,:/XA?*C.(,]KSE
M`,:/XA?*C.($]KSE`,:/XA?*C.+\];SE`,:/XA?*C.+T];SE`,:/XA?*C.+L
M];SE`,:/XA?*C.+D];SE`,:/XA?*C.+<];SE`,:/XA?*C.+4];SE`,:/XA?*
MC.+,];SE`,:/XA?*C.+$];SE`,:/XA?*C.*\];SE`,:/XA?*C.*T];SE`,:/
MXA?*C.*L];SE`,:/XA?*C.*D];SE`,:/XA?*C.*<];SE`,:/XA?*C.*4];SE
M`,:/XA?*C.*,];SE`,:/XA?*C.*$];SE`,:/XA?*C.)\];SE`,:/XA?*C.)T
M];SE`,:/XA?*C.)L];SE`,:/XA?*C.)D];SE`,:/XA?*C.)<];SE`,:/XA?*
MC.)4];SE`,:/XA?*C.),];SE`,:/XA?*C.)$];SE`,:/XA?*C.(\];SE`,:/
MXA?*C.(T];SE`,:/XA?*C.(L];SE`,:/XA?*C.(D];SE`,:/XA?*C.(<];SE
M`,:/XA?*C.(4];SE`!"@X0(`H.$'T,WC.0``Z@W`H.$PV"WI1""?Y40PG^4"
M((_@0$"?Y0,PDN<$0(_@`P!4X02P3.(PJ)TH`U"#X@0PA.(#4$7@`U#%XP-0
MA>`$,)3D,_\OX04`5.'[__\:,*B=Z.1S`0`(`0``X'(!``W`H.'PV"WI;""?
MY6P0G^5L,)_E`B"/X`%`DN<#,)+G!+!,X@,`5.'PJ)TH!"#4Y:``4N,/```:
M"$"$X@=P@^($<$?@!W#'XP1PA^`(4!3E!&"@X0`PE>4S_R_A!P!4X0``A>7P
MJ)T(!##6Y0A`A.*@`%/C]/__"BO__^N`<P$`+`$``!`!```-P*#A@-@MZ7"!
MG^4$L$SB#-!-X@!@4>((@(_@2P``"EPQG^4`();E`Q"8YU0QG^4`P)+E`&"!
MY0-PF.<(,);E``!<XP`PA^4Z```*.#&?Y0,0F.<`P('E`""2Y0`PTN4``%/C
M!0``"@$@@N(O`%/C`""!!0$PTN0``%/C^O__&@``4.,````*_/[_ZXO__^OX
M,)_E`S"8YP``4^,U```*[#"?Y>Q`G^4#,)CG!$"/X`,`5.$(```J`U"#X@0P
MA.(#4$7@`U#%XP-0A>`$,)3D,_\OX04`5.'[__\:N`"?Y;A`G^4``(_@Y/[_
MZ[`PG^4$0(_@`S"8YP,`5.$(```J`U"#X@0PA.(#4$7@`U#%XP-0A>`$,)3D
M,_\OX00`5>'[__\:`""7Y0`0EN4$`);E8PH`Z[;^_^M,()_E9#"?Y0(@F.<#
M,(_@`#""Y<O__^H3(*#C4#"?Y0`@C>4#,(_@`B"@XP0`H.,`$*#C_/[_ZP$`
MH./9_O_K?O__Z\?__^KT<@$`4`$``"@!``!8`0``2`$``!@!``!D<0$`+/[_
M_R!Q`0`T`0``I',!`.`K```-P*#AU#"?Y?#;+>D`@%#B!+!,X@%PH.$#,(_@
M*P``"KP@G^4",)/G`)"3Y0``6>,H```*`##8Y3U04^(!4*`3``!3XP!0H`,`
M`%7C$0``&@!`F>4``%3C#```"@E@H.$%(*#A"!"@X00`H.&4_O_K``!0XP(`
M`!H%,-3G/0!3XPL```H$0+;E``!4X_/__QH$`*#A\*N=Z`A0H.$!,/7E``!3
MXST`4Q/[__\:"%!%X.;__^H)8$;@`5"%XD9AH.$%0(3@`&"'Y00`H.'PJYWH
M"$"@X>W__^H)0*#AZ___ZD1Q`0`H`0``#<"@X?#8+>D$L$SB"-!-X@!0H.&`
M<)_E@#"?Y0=PC^`#8)?G)$!+X@`PEN4@,`OE!!"@X04`H.&V___K``!0XPX`
M``I8,)_E)!`;Y0,PE^<`()/E`3&"X`0`D^4``%#C`0&"Y_'__PH$,(/B!""3
MY0``4N,$((/D^___&NO__^H@(!OE`#"6Y0,`4N$!```:'-!+XO"HG>AV_O_K
M6'`!`#`!```H`0``#<"@X?#?+>D$L$SBK-!-XC0QG^4T(9_E`S"/X`)`D^<`
M8%#B`#"4Y3`P"^4"```*`##6Y0``4^,%```:,"`;Y0`PE.4#`%+A/@``&BC0
M2^+PKYWH;_[_ZP!P4.+V__\*[#"?Y>R`G^4#,(_@Z)"?Y=`P"^7,,$OB"("/
MX`F0C^#4,`OE!P"@X<O^_^L``%#C)0``"@U0@.(%`*#A"!"@X<+^_^L``%#C
M]?__"@D0H.$%`*#AO?[_ZP``4./P__\*!@"@X;#^_^L`H*#A!0"@X:W^_^L`
M`(K@`@"`XK#^_^L`H*#A!3"@X08@H.'0$!OEG/[_Z]00&^4*`*#A)/[_ZP$`
M<.,*`*#A`P``"L0P&^4/.@/B`0E3XP@```H3_O_K"@"@X0C^_^O5___J!P"@
MX37^_^L&`*#A\?W_Z[[__^JN___K]?__ZB#^_^NT;P$`,`$``.`I``#(*0``
MR"D```W`H.'PWRWI!+!,XA303>(!0*#A#)*?Y0PRG^4`(-'E"9"/X`-@F><]
M`%+C`4"!`@`PEN4`4*#A!`"@X3`P"^5Y_O_K-!!+X@!PH.$%`*#A+O__ZP"`
M4.(^```*<O[_ZP<`4.$U```JP#&?Y32`&^4#D)GG"(&@X0`PU>4]`%/B`0"@
M$P``4^,``*`#``!0XP4```H%`*#A`3#PY0``4^,]`%,3^___&@4`0.`"<(?B
M``"'X`!PF>5A_O_K``!0XP@`A^=4```*`##5Y0`@F>4]`%/C``!3$S00&^4!
M`(7B`1&2YP`PP>4&```*`2"!X@$PT.0"$*#A/0!3XP``4Q,!,,+D^?__&CTP
MH.,!(*#A`##!Y0$PU.0``%/C`3#BY?O__QH``*#C,"`;Y0`PEN4#`%+A.@``
M&BC02^+PKYWH`3!(X@$@U.0``%+C`2#CY?O__QKR___JT#"?Y0.0F><`()GE
M`*"2Y0``6N,($*`#"0``"@@PH.$"$*#A````Z@HPH.$$`+'E`:"#X@``4./Z
M__\:`S"#X@,1H.&0,)_E`S"/X```D^4``%#C$P``&@'`H.,!`*#A`,"#Y3P@
M"^4?_O_K`#!0XC@P"^42```*/"`;Y0J!H.$"$*#A"""@X6G]_^LX,!OE`#")
MY0`0H.,!((KB`A&#YS2@"^6=___J`@"@X5W]_^L``%#C`#"@X0``B>4*@:`1
M\___&@``X./`___JD?W_ZTQN`0`P`0``*`$``-AN`0`-P*#A,-@MZ02P3.*@
MT$WB<#"?Y7`@G^4#,(_@`D"3Y[002^(`,)3E`%"@X1@P"^5K_?_K``!0XP``
MH!,$```:K#`;Y0\Z`^(*"E/C`0E3$P4```H8(!OE`#"4Y0,`4N$'```:%-!+
MXC"HG>@%`*#A`A"@X[W]_^L0#V_AH`*@X?/__^IK_?_K'&P!`#`!```-P*#A
M\-@MZ40@G^5$`)_E1#"?Y02P3.("((_@``"/X#A0G^4X0)_E`V"2Y\_]_^L%
M4(_@!$"/X`4PH.$&(*#A!!"@X0``D.4<T$OB\&B=Z(3]_^J,:P$`J&P!`!0!
M``"X)0``]"4```W`H.$PV"WI5`"?Y0C03>($L$SB``"/X+K]_^L`4*#A``"0
MY=O__^L`$*#C-$"?Y30PG^4$0(_@`R"4YRPPG^4``)7E!!"-Y200G^4#,(_@
M`#"-Y0$0C^"#_?_K%-!+XC"HG>A(;`$`"&L!`%P!``!$*```B"4`````H.,>
M_R_A#<"@X?#?+>E-WDWB!+!,X@303>(P,I_E,"*?Y0,PC^`"()/G`$"@X1-]
M2^(@`I_E`#"2Y0QP1^(!4*#A``"/X`001^+@)`OE,#`+Y4/^_^LO$*#C`&"@
MX00`H.'M_/_K``!0XPL```KH`9_E!!"@X0``C^#U_O_K!`"@X>`T&^4P(!OE
M`#"3Y0,`4N%M```:*-!+XO"OG>@$`*#A=OW_Z[01G^4`@*#A`1"/X`4`H.$.
M_?_K`*!0XNK__PJ<,9_EG)&?Y0,PC^#D-`OEE#&?Y0,PC^#H-`OEC#&?Y0,P
MC^#8-`OEA#&?Y0,PC^#<-`OE`##:Y0``4^,T```*``!6XP0```H*$*#A!@"@
MX6/]_^L``%#C-@``"@H`H.%6_?_K`3!`X@,0VN<#,(K@+P!1XP4``!H`P*#C
M`,##Y0$@<^4!`$#B+P!2X_K__PH!,(CB``"#X`D`4.'"___*W#0;Y4->2^($
M,(WE`2N@X]@T&^4`$*#C"$"-Y0"@C>4%`*#A[_S_ZP<0H.$%`*#AO/S_ZP``
M4.,#```:Q#0;Y0\Z`^(""5/C&```"L00G^4``*#C`1"/X,W\_^L`H*#A``!:
MXZC__PH`,-KE``!3X\K__QH``%;C&```"N04&^4&`*#A+OW_ZP``4./DI!L5
M`0"@$]7__QI\$)_E``"@XP$0C^"Z_/_K`*"@X>O__^H!$*#C!0"@X??\_^L`
M`%#CX?__&E0`G^4%$*#A``"/X(?^_^L%`*#A^/S_ZX___^KHI!OE`0"@X\#_
M_^J<_/_KH&H!`#`!```X)0``$"4``.@D``!L)```_P,``&`D``"X)```6"<`
M`.`C``"4(P``6",````@T.4``%+C'O\O`0$P@.(O`%+C`P"@`0$@T^0``%+C
M^O__&A[_+^$-P*#A,-@MZ0!`4.($L$SB'```"@!0U.4``%7C&0``"NO\_^L!
M`$#B`""$X`(`5.$+```J`##4YR\`4^,M```:`3!"X@,``.H`$-/E`3!#XB\`
M4>,G```:!`!3X0,@H.'X__\:`@!4X0L``!HO`%7C+@``"L@`G^4``(_@%-!+
MXC!HG>BZ_/_JN`"?Y0``C^`4T$OB,&B=Z+7\_^H!($+B!```Z@`PTN4!$$+B
M+P!3XP(``!H!(*#A`@!4X?C__SH$($+@`C""X@$+4^,5``"*=%"?Y0$@@N(%
M4(_@!%"%X@00H.$%`*#A`3N@XT_\_^L%`*#A,*B=Z`$P0N(#``#J`!#3Y0$P
M0^(O`%'CXO__"@,`5.$#(*#A^/__.@(`5.'1__\*W/__Z@``H.,PJ)WH&`"?
MY0``C^`4T$OB,&B=Z(O\_^H@)0``_"$``$AI`0!4(0``#<"@X7#8+>D$L$SB
M--!-XK3!G^6T09_E#,"/X+!1G^4$0(_@#,",XD3@2^(%4)3G#P"\Z`\`KN@/
M`+SH#P"NZ)`!G^4`()SE`#"5Y0``C^"P(,[A(#`+Y7O]_^MX`9_E>&&?Y0``
MC^!W_?_K<`&?Y09@C^```(_@<_W_ZV0!G^5(0$OB``"/X&_]_^M8`9_E``"/
MX&S]_^M0`9_E``"/X&G]_^M(`9_E``"/X&;]_^M``9_E``"/X&/]_^L&`*#A
M8?W_ZS`!G^4``(_@7OW_ZR@!G^4``(_@6_W_ZR`!G^4$$*#A``"/X!W]_^L`
M$%#B`0``"@8`H.'5_?_K!`&?Y000H.$``(_@%?W_ZP`04.("```*\`"?Y0``
MC^#,_?_KZ`"?Y000H.$``(_@#/W_ZP`04.(-```*U`"?Y0``C^##_?_KS!"?
MY<P`G^4!$(_@``"/X+[]_^L@(!OE`#"5Y0,`4N$7```:&-!+XG"HG>BH`)_E
M!!"@X0``C^#X_/_K`!!0X@L``!J4$)_E"B"@XP$0C^`S`$OBHOO_ZP``4./G
M__\:?`"?Y2D02^(``(_@I_W_Z^+__^IL`)_E``"/X*/]_^O>___JO?O_Z^P@
M``"@9@$`,`$``%0A``!((0``@"$``$`A```\(0``."$``#PA``#0(```,"$`
M`#0A``"P(```)"$``!@A```8(0``%"$``#P@```@(0``>"```-0@``#0(```
M."```"@@```-P*#A$-@MZ02P3.(,T$WB?#"?Y7P0G^5\()_E`S"/X`(@C^`!
M0)/G``"2Y0`@E.4!`'#C&"`+Y04```H8(!OE`#"4Y0,`4N$0```:$-!+XA"H
MG>A$`)_E'!!+X@``C^"S_/_K``!0XP0```H``-#E,`!0XP``4!,!`*`3``"@
M`QPPG^4#,(_@``"#Y>K__^I_^__K=&0!`#`!``#890$`6!\``'1E`0`-P*#A
M`-@MZ02P3.+?^__KV/O_ZP``4.,``)`5`*B=Z`W`H.'PV2WI!+!,XA303>+$
M,)_EQ""?Y0,PC^`"0)/GO&"?Y0`PE.4&8(_@`%"@X2P02^(&`*#A*#`+Y8K\
M_^L`<%#B!1"@X1D```H`,-?E``!3XQ8```HK^__K``!0XQ8``!H%`*#AQOO_
MZP"`H.$'`*#AP_O_ZP``B.`"`(#BQOO_ZP"`H.%8,)_E6!"?Y0!PC>4%(*#A
M`S"/X`$0C^"O^__K"!"@X08`H.$J_?_K`@``ZC0`G^4``(_@)OW_ZR@@&^4`
M,)3E`P!2X0$``!H@T$OB\*F=Z#O[_^NP8P$`,`$``%`?```$'@``!!X``,`>
M```-P*#A\-\MZ8'<3>($L$SB/-!-XB#'G^6!+$OB'(>?Y0)I2^(,P(_@+&!&
MXD@@0N(,5Y_E``""Y0B`C^`1/D;B$$",XOC@1N(%4)CG!P"<Z0<`@^@/`+3H
M#P"NZ`,`E.B!/$OB@2Q+XBP@0N*!?$OB5#!#X@`@@^4HP(SB03]&XE!P1^(`
M0)7E`%"'Y0,`CN@44$+B!P"<Z`<`@^BD!I_E!1"@X0``C^`P0`OE,?S_ZP!`
M4.("```*`##4Y0``4^.;```:B/__ZP"@4.*=```*"@"@X6[[_^N``*#A`0"`
MXG'[_^L`(-KE@3Q+XDPP0^(``%+C``"#Y0L```J!/$OB3#!#XD!VG^4`0)/E
M!W"/X`0`H.$'$*#A5/O_ZP$@^N4"0(3B``!2X_C__QKX`!;E``!0XQ(```KT
M0$;B`@``Z@0`E.0``%#C#0``"@40H.$(_/_K`'!0XOC__PH`,-?E``!3X_7_
M_PI,_?_K``!0X_+__PH'`*#A+?O_ZP"@4.(:```:`)"@XX$\2^)4,$/B`#"3
MY1!`0^(),8;@$'$3Y0``5^,*```*`##7Y0``4^,'```*!P"@X3C]_^L``%#C
M`9")X@0``!H)<93G``!7X_3__QH`H*#C!```Z@<`H.$3^__K``!0X^K__PH`
MH*#A"@"@X2;[_^N!/$OB3#!#X@"0D^4`<*#A"0"@X2#[_^L``(?@`7N`X@1P
MA^('`*#A(?O_ZP!`H.$@-9_E(!6?Y0,PC^``,(WE&#6?Y0H@H.$#,(_@`1"/
MX`20C>4'^__K!`"@X0<=H./@^O_K`0!PXQX```K@$$;B!`"@X83Z_^L`D%#B
M`P``&M@P%N4/.@/B`0E3XTL```K,))_ES!2?Y0(`F.>!+$OB2"!"X@`@DN4$
M,*#A`""2Y;``@.(!$(_@?_K_ZP!PH..!/$OB4#!#X@`PD^4P(!OE`#"3Y0<`
MH.$#`%+A%P$`&BC02^+PKYWHM?K_ZP`PD.41`%/CW/__"H$\2^)(,$/B`#"3
MY0!PH.,`4)/EK/K_ZTPTG^4`$)#E`P"8YP`0C>5$%)_E!2"@X00PH.&P`(#B
M`1"/X&#Z_^O@___J]/[_ZP0`H.&\^O_K`'"@X=O__^H*<*#A@4Q+XC!`1.('
M`93G``!0XPP```H%$*#A@_O_ZP`P4.(!<(?B]___"@`PT^4``%/C]/__"JOZ
M_^L``%#C\?__"@"@H.%.___J#0"@X\/Z_^O$HY_E@3Q+XDPP0^(``(/E"J"/
MX%,@H.-0___JQ*`6Y:[Z_^L``%KAK___&M@P%N6#.Z#AHSN@X0<-4^.J__\:
M!P"@X;'Z_^L`<*#A?`.?Y040H.$``(_@7_O_ZP``4.-4```*@3Q+XD@P0^(`
M,)/E`%"3Y8?Z_^L`$*#A!0"@X?W\_^L`4%#B2@``"@4`H.&8^O_K`P!0XP"`
MH.$,``":+!.?Y00`0.(``(7@`1"/X)GZ_^L``%#C!0``&@0`6.."```*"("%
MX`4P6.4O`%/C?@``"G/^_^L`$%#B`P``&@4`H.%T^O_K`%!0XC8``!K@$I_E
MX`*?Y0$0C^```(_@\?O_ZUWZ_^O0,I_ET!*?Y0,PC^`)`(WHR#*?Y<B"G^7(
M8I_ER%*?Y0,PC^`$(*#A`1"/X`<`H.%E^O_K"("/X`9@C^`%4(_@#```ZC/Z
M_^L`,)#E$0!3XPT``!I'^O_K`9")X@$"C>@(4(WE"#"@X00@H.$&$*#A!P"@
MX53Z_^L'':#C!P"@X2WZ_^L!`'#C[?__"@0`H.'&^?_K5`*?Y0<0H.$``(_@
MQ_O_ZP<`H.%N_O_K6/__ZH$\2^)(,$/B`#"3Y0!0D^6O___J`I"@XP`PX.,1
M(.#C`)"-Y02`1N(R^O_K"!"@X08@H.,%`*#A]?G_ZP0P5N4``%/C`@``&@,P
M5N5#`%/C0@``"@`0H.,`(*#C`#"@XP`0C>4%`*#A(OK_ZTD$`.L`D*#A`@``
MZ@@0H.$)`*#A7`0`ZP(IH.,($*#A!0"@X=_Y_^L`(%#B]O__R@4`H.%$4$;B
MB?G_ZS"`1N()$*#A!0"@X8H$`.L(H*#A@)&?Y0F0C^`!(-7D"@"@X0D0H.$1
M^O_K!0!8X0*@BN+X__\:``"@XUPQG^5<$9_E`S"/X`0PC>54,9_E`("-Y0,P
MC^`(`$;E!""@X0$0C^`'`*#A`?K_Z[#__^J!/$OB2#!#X@`PD^4$@)/E``!8
MXWK__PH(`*#A`?K_ZP,`4.-V__^:#!&?Y00`0.(``(C@`1"/X`/Z_^L``%#C
M"%"@`6[__^H",%;E00!3X[G__QH!,%;E0P!3X[;__QH`,-;E2`!3X[/__QH!
M,-;E10!3X[#__QH`,.#C`)"-Y3D@X.,%`*#AU/G_ZP@0H.$%`*#A*2"@XY?Y
M_^N<,)_EG!"?Y0,PC^`$,(WEE#"?Y0"`C>4#,(_@!""@X0$0C^`'`*#ASOG_
MZWW__^IF^?_K&&0!`)QB`0`P`0``Z!P``)`=``"`'```8!P``!@>``!4`0``
M2!P``)`;``#H&@``6!L```@;``#L&0``8!D``'P;``"D&@``E!L``(`;``"D
M&@``2!L``$P8``"(&```Z!D```09```(&@``N!@``!@9```X&```.!D```W`
MH.'PV2WI!+!,X@S03>)@,I_E8"*?Y0,PC^`"4)/G6`*?Y0`@E>4``(_@*"`+
MY:SY_^L`,)#E1`*?Y60@T^4L8$OB!A"@X0``C^!E(,/E6OK_ZP``4.,"```*
M`##0Y3$`4^->```*^_S_ZQ0"G^440I_E``"/X)KY_^L$0(_@!!"@X0!PH.$#
M,*#C``"0Y0$@H.,_^?_K`$!0X@H```H,,)3EY"&?Y0`0D^4"((_@``"7Y1SY
M_^L,,)3E`!"3Y0@PD>4!!1/C5```&L`!G^7`09_E``"/X(+Y_^L$0(_@!!"@
MX0!PH.$#,*#C``"0Y0$@H.,G^?_K`$!0X@D```J4`9_E!A"@X0``C^`K^O_K
M`"!0XC8```H,,)3E``"7Y0`0D^4`^?_K<`&?Y7"!G^4``(_@:_G_ZV@1G^4`
M<)#E`$"@X0$@H.,!$(_@!P"@X1SY_^M0(9_E`!"@X0(@C^`'`*#A\/C_ZP`@
MH.,`,)3E.`&?Y080H.%E(,/E``"/X`[Z_^L(@(_@``!0XP@$B.4+```*!QV@
MXR+Y_^L!,(#B$0!0XP$`4Q,I``"**"`;Y0`PE>4#`%+A)```&B#02^+PJ9WH
M!`28Y9[]_^L``%#C"`2(Y>[__QK4`)_E``"/X/OX_^L!,-#E``!3XY[__PJ<
M___JE_O_ZP"`4.(*```*##"4Y0``E^4`$)/E"""@X<7X_^L(`*#AG_C_Z\'_
M_^H``)?E_/C_ZZ?__^J$,)_E#""4Y0,PC^`$-)/E`!"2Y0``E^4`()/EM_C_
MZ[7__^JR^/_K8""?Y0`PH.$"((_@!!22Y50`G^4())+E`!"1Y0``C^#6^/_K
M!%L!`#`!```47`$`W!4``,A;`0!@%P``-!<``&A;`0`,%P``V!0```Q;`0"D
M6P$`I!8``*@6``!8%```,!8``/1:`0#,6@$`P!4```W`H.$PV"WI!+!,X@!`
MH.$+_/_K`/S_ZP!0H.'I_/_K``!0XP``5!,PJ)T(`##4Y0``4^,PJ)T()!"?
MY04`H.$$(*#C`1"/X%SX_^L``%#C,*B=&`0`H.$4T$OB,&B=Z`GZ_^KP$P``
M#<"@X?#?+>D$L$SB5=]-XEW/2^(,X*#AT#N?Y=`KG^4#,(_@`B"3YQP0@.)X
M(0OE`""2Y5Q`@.(P(`OE!""1Y&(X(N`C-*#A_SS#XV(T(^`!`%3A!#"NY??_
M_QITX$OB.#"<Y21`G.4,$)SE!#`CX`0@O.4!,"/@`C`CX.,_H.$.`%SA0#",
MY?3__QH$$)#E8#N?Y0C`D.5P(1OE`$"0Y6%AH.$0@)#E;!$;Y0S@D.4&4"S@
M`R""X`@@@N`$4`7@!("0Y0,0@>`.<"S@#%`EX`X0@>`!D(7@"'`'X&@1&^5D
M@:#A#G`GX.0M@N`'((+@9*$;Y0-P@>`($";@8E&@X0(0`>`,<(?@XBV)X`.@
MBN`%D"C@!A`AX`<0@>`&8(K@8G&@X0*0">!@H1OEXBV!X`B0*>`'$"7@!I")
MX`.@BN`"$`'@8F&@X>*=B>`(H(K@!2`AX%P1&^4&@"?@"B""X.DM@N`#H('@
M"8`(X&D1H.%8D1OE!X`HX`6@BN`!4";@"J"(X`.0B>`"@`7@!Y")X`:`*.!B
M4:#AXBV*X`F@B.!4@1OE!7`AX`.0B.`"@`?@!I")X`&`*.!B<:#AXBV*X`F@
MB.!0@1OE!V`EX`.0B.`"@`;@`9")X`6`*.!B8:#AXBV*X`F@B.!,@1OE!A`G
MX`.0B.`"@`'@!9")X`>`*.!B$:#AXBV*X`F@B.!(@1OE`5`FX`.0B.`"@`7@
M!Y")X`:`*.!B4:#AXBV*X`F@B.!$@1OE!7`AX`.0B.`"<`?@!I")X`%P)^!B
M@:#AXBV*X`F@A^!`<1OE"&`EX`.0A^`"<`;@8F&@X05P)^#B+8K@`1")X#RA
M&^4&D"C@`1"'X`*0">!B<:#A`Z"*X.(M@>`($"G@.)$;Y06@BN`'4";@"A"!
MX`.@B>`"D`7@"("*X`:@*>!B4:#A"*"*X#2!&^7B'8'@!2`GX`.0B.`!(`+@
M88&@X>&MBN`&8(G@!Q`BX`80@>`P81OE""`EX`.0AN#J'8'@:F&@X0H@`N`L
MH1OE!W")X`4@(N`&D"C@!R""X`&0">`#<(K@**$;Y>$M@N`%4(?@81&@X0B0
M*>`#H(K@!9")X`%0)N!B<:#AXIV)X`)0!>`(((K@)*$;Y0>`(>`&4"7@"8`(
MX`)0A>`#,(K@E"B?Y2"A&^4&,(/@`6`HX&F!H.'IG87@`U"&X`)@BN`(,"?@
M'*$;Y0$0AN`)8"/@:3&@X>E=A>`&8('@&)$;Y0(0BN`#H"C@!:`JX`<0@>!E
M<:#AY6V&X`H0@>`"4(G@%*$;Y0>0(^`&D"G@"%"%X&:!H.'F'8'@"5"%X`*@
MBN`(D"?@X6V%X`,PBN`!4"G@!5"#X!`Q&^5A$:#A#)$;Y0*@@^`!,"C@!Z"*
MX`8P(^!F<:#AYEV%X`,PBN`"8(G@"*$;Y0>0(>`%D"G@"&"&X&6!H.'E/8/@
M"6"&X`A0)^`"D(K@!*$;Y>-MAN`!$(G@`U`EX&,QH.$`D1OE!5"!X`*@BN`#
M$"C@!Z"*X`80(>!F<:#AYEV%X`$0BN`"8(G@_*`;Y0>0(^`%D"G@"&"&X&6!
MH.'E'8'@"6"&X`A0)^`"D(K@^*`;Y>%MAN`#,(G@`5`EX&$1H.'TD!OE!5"#
MX`*@BN`!,"C@!Z"*X`8P(^!F<:#AYEV%X`,PBN`"8(G@\*`;Y0>0(>`%D"G@
M"&"&X&6!H.'E/8/@"6"&X`A0)^`"D(K@[*`;Y>-MAN`!$(G@`U`EX&,QH.'H
MD!OE!5"!X`*@BN`#$"C@!Z"*X`80(>!F<:#AYEV%X`$0BN`"8(G@Y*`;Y0>0
M(^`(8(;@!8`IX&61H.'E'8'@"("&X`)@BN`)H"?@`S"&X`%@*N`&8(/@X#`;
MY>%=B.!A$:#AW(`;Y0*@@^`!,"G@!Z"*X`4P(^!E<:#AY6V&X`,PBN`"4(C@
MV*`;Y0>`(>`)4(7@!H`HX&:1H.$"H(K@YFV#X`B`A>`),"?@U%`;Y>:-B.`!
M$(K@!C`CX&9AH.$"H(7@`S"!X`80*>!H4:#AZ"V#X`=PBN`!@"C@!#:?Y0B@
MA^#0<!OE!1"&X0.`A^`"$`'@8G&@X>(MBN`%H`;@"9"(X`J@@>',$!OE!X"%
MX0F@BN`"@`C@`Y"!X&(1H.'B+8K@!Z`%X`9@B>`*H(CAR)`;Y0&`A^$&H(K@
M`Y")X&)AH.$"@`C@XBV*X`&@!^`%4(G@"J"(X<20&^4&@('A!:"*X`.0B>!B
M4:#A`H`(X.(MBN`&H`'@!W")X`J@B.'`D!OE!8"&X0>@BN`#D(G@8G&@X0*`
M".#B+8K@!:`&X`$0B>`*H(CAO)`;Y0>`A>$!H(K@`Y")X&(1H.$"@`C@XBV*
MX`>@!>`&8(G@"J"(X;B0&^4!@(?A!J"*X`.0B>!B8:#A`H`(X.(MBN`!H`?@
M!5")X`J@B.&TD!OE!H"!X06@BN`#D(G@8E&@X0*`".#B+8K@!J`!X`=PB>`*
MH(CAL)`;Y06`AN$'H(K@`Y")X&)QH.$"@`C@XBV*X`6@!N`!$(G@"J"(X:R0
M&^4'@(7A`:"*X`.0B>!B$:#A`H`(X.(MBN`'H`7@!F")X`J@B.&HD!OE`8"'
MX0:@BN`#D(G@8F&@X0*`".#B+8K@`:`'X`50B>`*H(CAI)`;Y0:`@>$%H(K@
M`Y")X&)1H.$"@`C@XBV*X`:@`>`'<(G@"J"(X:"0&^4%@(;A!Z"*X`.0B>!B
M<:#A`H`(X.(MBN`%H`;@`1")X`J@B.&<D!OE!X"%X0&@BN`#D(G@8A&@X0*`
M".#B+8K@!Z`%X`9@B>`*H(CAF)`;Y0&`A^$&H(K@`Y")X&)AH.$"@`C@XBV*
MX`&@!^`%4(G@"J"(X920&^4&@('A!:"*X`.0B>!B4:#A`H`(X.(MBN`&H`'@
M!W")X`J@B.&0D!OE!8"&X0>@BN`#D(G@8G&@X0*`".#B+8K@!:`&X`$0B>`*
MH(CAC)`;Y0>`A>$!H(K@`Y")X&(1H.$"@`C@XBV*X`>@!>`&8(G@"J"(X8B0
M&^4!@(?A!J"*X`.0B>!B8:#A`H`(X.(MBN`!H`?@!9")X`J`B.$)@(C@A)`;
MY090@>$#,(G@!W"#X`:0`>#T,I_E`E`%X("@&^7BC8C@"5"%X6(AH.%\D!OE
M!U"%X`-PBN`"H";@"*`JX`$0A^!H<:#AZ%V%X`H0@>`#@(G@>*`;Y0>0(N`%
MD"G@!H"(X&5AH.'E'8'@"8"(X`90)^`#D(K@=*`;Y>&-B.`"((G@`5`EX&$1
MH.%PD!OE!5""X`.@BN`!(";@!Z"*X`@@(N!H<:#AZ%V%X`(@BN`#@(G@;*`;
MY0>0(>`%D"G@!F"(X&6!H.'E+8+@"6"&X`A0)^`#D(K@:*`;Y>)MAN`!$(G@
M`E`EX&(AH.%DD!OE!5"!X`.@BN`"$"C@!Z"*X`80(>!F<:#AYEV%X`$0BN`#
M8(G@8*`;Y0>0(N`%D"G@"&"&X&6!H.'E'8'@"6"&X`A0)^`#D(K@7*`;Y>%M
MAN`"((G@`5`EX&$1H.%8D!OE!5""X`.@BN`!("C@!Z"*X`8@(N!F<:#AYEV%
MX`(@BN`#8(G@5*`;Y0>0(>`%D"G@"&"&X&6!H.'E+8+@"6"&X`A0)^`#D(K@
M4*`;Y>)MAN`!$(G@`E`EX&(AH.%,D!OE!5"!X`.@BN`"$"C@!Z"*X`80(>!F
M<:#AYEV%X`$0BN`#8(G@2*`;Y0>0(N`(8(;@!8`IX&61H.'E'8'@"("&X`-@
MBN`)H"?@`B"&X`%@*N`&8(+@1"`;Y>%=B.!A$:#A`Z""X$"`&^4!("G@!Z"*
MX`4@(N!E<:#AY6V&X`(@BN`#4(C@/*`;Y0>`(>`&@"C@"5"%X&:1H.'F+8+@
M"%"%X`.@BN`)@"?@XFV%X`%0BN`"$"C@-*`;Y0$0A>`X4!OE8B&@X0.`A>`#
M,(K@`E`IX&:AH.'F'8'@!W"(X`0P@^`*@"+@!E`EX`&`*.`),(/@!5"'X.%=
MA>`(@(/@Y3V(X&$1C.!X01OE$,"0Y0`P@.4"((S@,#`;Y03`D.4`0)3E!5",
MX`K@CN`$`%/A"!"`Y1`@@.4$4(#E#."`Y0$``!HHT$OB\*^=Z(#U_^O05P$`
M,`$``)EY@EJAZ]ENW+P;C];!8LH-P*#A8`"@XS#8+>D$L$SBZO7_ZP`@H.,L
M$)_E+$"?Y2S@G^4LP)_E`!"`Y2@0G^400(#I#,"`Y1`0@.44((#E&""`Y5P@
M@.4PJ)WH`2-%9XFKS>_^W+J8=E0R$/#ATL,-P*#A\-LMZ10PD.4"8*#A@B&@
MX0(PD^``(*#C`2"@(P!0H.$``%+C&""0Y5P`D.4!(((2IBZ"X```4.,$L$SB
M`4"@X1@@A>44,(7E''"%X@X```I`@&#B"`!6X0:`H+$``(?@"""@X4'U_^M<
M,)7E`S"(X$``4^-<,(7E\*N=&`4`H.$(8$;@"$"$X,'\_^L_`%;C#@``VD!@
M1N(FDZ#A`8")X@B#A.!`(*#C!!"@X0<`H.$"0(3@+?7_ZP4`H.&T_/_K"`!4
MX?;__QH)G6G@"6.&X`00H.$'`*#A!B"@X2/U_^M<8(7E\*N=Z`W`H.'PVRWI
M`4"@X7\0X.,48)3E'("$XJ8QH.$_,`/B`2"#XC@`4N,`4*#A&'"4Y02P3.(#
M$,CG`@"(X$D``-I`(&+B`!"@XRSU_^L$`*#AE?S_ZP@`H.$X(*#C`!"@XR;U
M_^LG/*#A)BR@X2<(H.$G%*#A6V#$Y50PQ.4F.*#A)F2@X54`Q.59,,3E!`"@
MX5=PQ.56$,3E6"#$Y5I@Q.6!_/_K`S#4Y00`H.$`,,7ELC#4X0$PQ>4`,)3E
M(S2@X0(PQ>4`,)3E`S#%Y0<PU.4$,,7EMC#4X04PQ>4$,)3E(S2@X08PQ>4$
M,)3E!S#%Y0LPU.4(,,7ENC#4X0DPQ>4(,)3E(S2@X0HPQ>4(,)3E"S#%Y0\P
MU.4,,,7EOC#4X0TPQ>4,,)3E(S2@X0XPQ>4,,)3E#S#%Y1,PU.40,,7ELC'4
MX1$PQ>40,)3E(S2@X1(PQ>40,)3E$S#%Y2302^+P:YWHK/3_ZC@@8N(`$*#C
MXO3_Z[K__^H-P*#A,-@MZ6`PG^5@0)_E`S"/X"0@T^4$0(_@``!2XP2P3.(P
MJ)T8`1"@XT0@G^4D$,/E`C"4YP``4^,"```*-#"?Y0,`G^>`]/_K+#"?Y0,P
ME.<``%/C,*B=""``G^4``(_@%-!+XC!HG>CI]/_J^$H!``Q)`0`,`0``1$H!
M`$`!```\0P``/!"?Y3PPG^4!$(_@`"#1Y0,PC^```%+C'O\O$0$`H.,D()_E
M``#!Y0(PD^<``%/C'O\O`10`G^4$$('B``"/X-OT_^IX2@$`C$@!`$0!``#8
M0@``#<"@X?#8+>D$L$SB(-!-XB!2G^4@,I_E!5"/X"@`"^4L$`OE,"`+Y0-`
ME><P($OB`#"4Y2P02^(H`$OB(#`+Y:CT_^OT(9_E]#&?Y0(@E><#`)7G`A"@
MX:[T_^OD,9_E`S"5YP!@T^4``%;C3P``"M0!G^4``(_@Y?3_ZP`@D.4H8!OE
M/C/2Y00`AN(#,(/C!P%PXSXSPN4#8(;B60``B@`!H.&#]/_K`,"@X2PP&^68
M(9_EF!&?Y0``D^4"((_@!,2"Y0$0C^"((9_E``",Y000C.4"$)7G*"`;Y0``
MD>5T$9_E`0!2XP$0C^`,$(SE"`",Y1`0H-,(``#:!.!#X@+ACN`,$(SB!`"S
MY0X`4^$$`*'E^___&@,@@N("$:#A`."@XS11G^4!X(SG,!&?Y050C^`&(*#A
M#`25Y0PPH.$`X(WE`1"/X(?T_^L`8%#B*```"@Q1G^4D<$OB!5"/X`P$E>4U
M]/_K_`"?Y0<0H.$``(_@7/7_ZP``4.,8```*Z#"?Y0,PC^`,!)/E'/3_ZV/T
M_^L@(!OE`#"4Y08`H.$#`%+A(```&AS02^+PJ)WH+O3_Z[@PG^4``%#C`S"/
MX`P$@^49```*`?3_ZZ0`G^4``(_@CO3_ZP`PD.7#9L/EHO__Z@@$E>4``%#C
M!@``"G[[_^OA___J#`25Y6ST_^L`8*#ATO__ZF/T_^MH`)_E!Q"@X0``C^`S
M]?_K``!0XP@$A>75__\*\/__Z@;T_^L!`*#CQ?/_ZS!(`0`P`0``/`$``$P!
M```<`0``]$@!`)A)`0#<!```.`$``+P$```D20$`P-O___A(`0#P`0``T$@!
M`)A(`0"81P$`[````'!S7W-T<FEN9W,@;6ES<VEN9PH`<&5R;'AS:2YC````
M7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@("``````+@```"XN```E
M<R\E<P```$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO861E<@!);G1E<FYA;',Z
M.E!!4CHZ0D]/5`````!005)?5$5-4`````!005)?4%)/1TY!344`````.@``
M`"5S)7,E<P``4$523#5,24(`````4$523$Q)0@!015),-4]05`````!015),
M24\``%!!4E])3DE424%,25I%1`!005)?4U!!5TY%1`!005)?0TQ%04X```!0
M05)?1$5"54<```!005)?0T%#2$4```!005)?1TQ/0D%,7T1%0E5'`````%!!
M4E]'3$]"04Q?5$U01$E2````4$%27U1-4$1)4@``4$%27T=,3T)!3%]414U0
M`%!!4E]'3$]"04Q?0TQ%04X`````4$%27T-,14%./0``,0```$Q$7TQ)0E)!
M4EE?4$%42`!365-414T``"4P,G@`````)7,E<R5S)7,`````<&%R+0`````E
M<SH@8W)E871I;VX@;V8@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D
M("AE<G)N;STE:2D*```E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@
M=6YS869E("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A
M=&EO;BD*``!0051(`````'!A<FP`````+G!A<@`````E<R5S8V%C:&4M)7,E
M<P``)7,E<W1E;7`M)74E<P```"5S)7-T96UP+25U+25U)7,`````&````'!E
M<FP`````,````%!!4CHZ4&%C:V5R.CI615)324].`````#$N,#4R````56YA
M8FQE('1O(&-R96%T92!C86-H92!D:7)E8W1O<GD`````)7,Z(&-R96%T:6]N
M(&]F('!R:79A=&4@8V%C:&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R
M;F\])6DI"@`````M90``+2T``%5315(`````55-%4DY!344`````5$5-4$1)
M4@!435``+W1M<"\```!E=F%L("=E>&5C("]U<W(O8FEN+W!E<FP@("U3("0P
M("1[,2LB)$`B?2<*:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H
M96QL"G!A8VMA9V4@7U]P87)?<&P["FUY("@D4$%27TU!1TE#+"`D<&%R7W1E
M;7`L("1P<F]G;F%M92P@0'1M<&9I;&4L("5-;V1U;&5#86-H92D["D5.1"![
M(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*<F5Q=6ER92!&:6QE.CI496UP.PIR
M97%U:7)E($9I;&4Z.D)A<V5N86UE.PIR97%U:7)E($9I;&4Z.E-P96,["FUY
M("1T;W!D:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R7W1E;7`I
M.PIO=71S*'%Q6U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B72D["D9I
M;&4Z.D9I;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R;61I<B`Z('5N
M;&EN:R!]+"`D<&%R7W1E;7`I.PIR;61I<B`D<&%R7W1E;7`["FEF("@M9"`D
M<&%R7W1E;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PIM>2`D=&UP(#T@;F5W
M($9I;&4Z.E1E;7`H"E1%35!,051%(#T^("=T;7!86%A86"<L"D1)4B`]/B!&
M:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*4U5&1DE8(#T^("<N
M8VUD)RP*54Y,24Y+(#T^(#`L"BD["FUY("1F:6QE;F%M92`]("1T;7`M/F9I
M;&5N86UE.PIP<FEN="`D=&UP(#P\(BXN+B(["G@],3L@=VAI;&4@6R!<)'@@
M+6QT(#$P(%T[(&1O"G)M("UR9B`G)'!A<E]T96UP)PII9B!;(%PA("UD("<D
M<&%R7W1E;7`G(%T[('1H96X*8G)E86L*9FD*<VQE97`@,0IX/6!E>'!R(%PD
M>"`K(#%@"F1O;F4*<FT@)R1F:6QE;F%M92<*+BXN"F-L;W-E("1T;7`["F-H
M;6]D(#`W,#`L("1F:6QE;F%M93L*;7D@)&-M9"`]("(D9FEL96YA;64@/B]D
M978O;G5L;"`R/B8Q("8B.PIS>7-T96TH)&-M9"D["F]U=',H<7%;4W!A=VYE
M9"!B86-K9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A;G5P.B`D9FEL
M96YA;65=*3L*?0I]('T*0D5'24X@>PI);G1E<FYA;',Z.E!!4CHZ0D]/5"@I
M(&EF(&1E9FEN960@)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PHD4$%27TU!1TE#
M(#T@(EQN4$%2+G!M7&XB.PIE=F%L('L*7W!A<E]I;FET7V5N=B@I.PIM>2`D
M<75I970@/2`A)$5.5GM005)?1$5"54=].PIM>2`E0V]N9FEG(#T@*`IP871H
M7W-E<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG*2P*7V5X
M92`@("`@("`@/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC>6=W:6XI+R`_
M("<N97AE)R`Z("<G*2P*7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O7DU35VEN
M?$]3,B\@/R`G7%PG(#H@)R\G*2P**3L*7W-E=%]P<F]G;F%M92@I.PI?<V5T
M7W!A<E]T96UP*"D["FUY("@D<W1A<G1?<&]S+"`D9&%T85]P;W,I.PI["FQO
M8V%L("1324=[7U]705).7U]](#T@<W5B('M].PIO<&5N(%]&2"P@)SPZ<F%W
M)RP@)'!R;V=N86UE(&]R(&QA<W0["FUY("1B=68["FUY("1S:7IE(#T@+7,@
M)'!R;V=N86UE.PIM>2`D8VAU;FM?<VEZ92`](#8T("H@,3`R-#L*;7D@)&UA
M9VEC7W!O<SL*:68@*"1S:7IE(#P]("1C:'5N:U]S:7IE*2!["B1M86=I8U]P
M;W,@/2`P.PI](&5L<VEF("@H;7D@)&T@/2`D<VEZ92`E("1C:'5N:U]S:7IE
M*2`^(#`I('L*)&UA9VEC7W!O<R`]("1S:7IE("T@)&T["GT@96QS92!["B1M
M86=I8U]P;W,@/2`D<VEZ92`M("1C:'5N:U]S:7IE.PI]"G=H:6QE("@D;6%G
M:6-?<&]S(#X](#`I('L*<V5E:R!?1D@L("1M86=I8U]P;W,L(#`["G)E860@
M7T9(+"`D8G5F+"`D8VAU;FM?<VEZ92`K(&QE;F=T:"@D4$%27TU!1TE#*3L*
M:68@*"AM>2`D:2`](')I;F1E>"@D8G5F+"`D4$%27TU!1TE#*2D@/CT@,"D@
M>PHD;6%G:6-?<&]S("L]("1I.PIL87-T.PI]"B1M86=I8U]P;W,@+3T@)&-H
M=6YK7W-I>F4["GT*;&%S="!I9B`D;6%G:6-?<&]S(#P@,#L*<V5E:R!?1D@L
M("1M86=I8U]P;W,@+2`T+"`P.PIR96%D(%]&2"P@)&)U9BP@-#L*<V5E:R!?
M1D@L("1M86=I8U]P;W,@+2`T("T@=6YP86-K*").(BP@)&)U9BDL(#`["B1D
M871A7W!O<R`]('1E;&P@7T9(.PIM>2`E<F5Q=6ER95]L:7-T.PIR96%D(%]&
M2"P@)&)U9BP@-#L@("`@("`@("`@("`@("`@("`@("`@("`@("`C(')E860@
M=&AE(&9I<G-T(")&24Q%(@IW:&EL92`H)&)U9B!E<2`B1DE,12(I('L*<F5A
M9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D
M8G5F*3L*;7D@)&9U;&QN86UE(#T@)&)U9CL*;W5T<RAQ<5M5;G!A8VMI;F<@
M1DE,12`B)&9U;&QN86UE(BXN+ETI.PIM>2`D8W)C(#T@*"`D9G5L;&YA;64@
M/7X@<WQ>*%MA+69<9%U[.'TI+WQ\("D@/R`D,2`Z('5N9&5F.PIM>2`H)&)A
M<V5N86UE+"`D97AT*2`]("@D8G5F(#U^(&U\*#\Z+BHO*3\H+BHI*%PN+BHI
M?"D["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K
M*").(BP@)&)U9BD["FEF("AD969I;F5D*"1E>'0I(&%N9"`D97AT("%^("]<
M+B@_.G!M?'!L?&EX?&%L*20O:2D@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A
M<R@B)&-R8R1E>'0B+"`D8G5F+"`P-S4U*3L*)%!!4CHZ2&5A=GDZ.D9U;&Q#
M86-H97LD9G5L;&YA;65](#T@)&9I;&5N86UE.PHD4$%2.CI(96%V>3HZ1G5L
M;$-A8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA;64["GT*96QS:68@*"`D9G5L
M;&YA;64@/7X@;7Q>+S]S:&QI8B]\(&%N9"!D969I;F5D("1%3E9[4$%27U1%
M35!]("D@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B)&)A<V5N86UE)&5X
M="(L("1B=68L(#`W-34I.PIO=71S*")32$Q)0CH@)&9I;&5N86UE7&XB*3L*
M?0IE;'-E('L*)')E<75I<F5?;&ES='LD9G5L;&YA;65](#T*)$UO9'5L94-A
M8VAE>R1F=6QL;F%M97T@/2!["F)U9B`]/B`D8G5F+`IC<F,@/3X@)&-R8RP*
M;F%M92`]/B`D9G5L;&YA;64L"GT["GT*<F5A9"!?1D@L("1B=68L(#0["GT*
M;&]C86P@0$E.0R`]("AS=6(@>PIM>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\[
M"G)E='5R;B!I9B!R968@)&UO9'5L92!O<B`A)&UO9'5L93L*;7D@)&EN9F\@
M/2!D96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?2!O<B!R971U<FX["B1)
M3D-[)&UO9'5L97T@/2`B+VQO861E<B\D:6YF;R\D;6]D=6QE(CL*:68@*"1%
M3E9[4$%27T-,14%.?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z.FYE=RDI('L*
M;7D@)&9H(#T@24\Z.D9I;&4M/FYE=U]T;7!F:6QE(&]R(&1I92`B0V%N)W0@
M8W)E871E('1E;7`@9FEL93H@)"$B.PHD9F@M/F)I;FUO9&4H*3L*)&9H+3YP
M<FEN="@D:6YF;RT^>V)U9GTI.PHD9F@M/G-E96LH,"P@,"D["G)E='5R;B`D
M9F@["GT*96QS92!["FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D:6YF;RT^
M>V-R8WTN<&TB+"`D:6YF;RT^>V)U9GTI.PIO<&5N(&UY("1F:"P@)SPZ<F%W
M)RP@)&9I;&5N86UE(&]R(&1I92!Q<5M#86XG="!R96%D("(D9FEL96YA;64B
M.B`D(5T["G)E='5R;B`D9F@["GT*9&EE(")";V]T<W1R87!P:6YG(&9A:6QE
M9#H@8V%N)W0@9FEN9"!M;V1U;&4@)&UO9'5L92$B.PI]+"!`24Y#*3L*<F5Q
M=6ER92!84TQO861E<CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E($-A
M<G`Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*4$%2.CI(96%V
M>3HZ7VEN:71?9'EN86QO861E<B@I.PIR97%U:7)E($E/.CI&:6QE.PIW:&EL
M92`H;7D@)&9I;&5N86UE(#T@*'-O<G0@:V5Y<R`E<F5Q=6ER95]L:7-T*5LP
M72D@>PIU;FQE<W,@*"1)3D-[)&9I;&5N86UE?2!O<B`D9FEL96YA;64@/7X@
M+T)31%!!3B\I('L*:68@*"1F:6QE;F%M92`]?B`O7"YP;6,_)"]I*2!["G)E
M<75I<F4@)&9I;&5N86UE.PI]"F5L<V4@>PID;R`D9FEL96YA;64@=6YL97-S
M("1F:6QE;F%M92`]?B`O<VET96-U<W1O;6EZ95PN<&PD+SL*?0I]"F1E;&5T
M92`D<F5Q=6ER95]L:7-T>R1F:6QE;F%M97T["GT*;&%S="!U;FQE<W,@)&)U
M9B!E<2`B4$M<,#`S7#`P-"(["B1S=&%R=%]P;W,@/2`H=&5L;"!?1D@I("T@
M-#L@("`@("`@("`@("`@("`@(R!S=&%R="!O9B!Z:7`*?0IM>2!`<&%R7V%R
M9W,["FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L("1C86-H95]N86UE*3L*
M9&5L971E("1%3E9[4$%27T%04%]2155317T[(",@<V%N:71I>F4@*%)%55-%
M(&UA>2!B92!A('-E8W5R:71Y('!R;V)L96TI"B1Q=6EE="`](#`@=6YL97-S
M("1%3E9[4$%27T1%0E5'?3L*:68@*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP
M72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2!["FUY("5D:7-T7V-M
M9"`]('%W*`IP("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A;&Q?<&%R"G4@("!U
M;FEN<W1A;&Q?<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R:69Y7W!A<@HI.PII
M9B`H0$%21U8@86YD("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@>PIS:&EF="!`
M05)'5CL*)$5.5GM005)?05!07U)%55-%?2`]('-H:69T($!!4D=6.PI]"F5L
M<V4@>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`861D7W1O7VEN8SL*
M=VAI;&4@*$!!4D=6*2!["B1!4D=66S!=(#U^("]>+2A;04E-3T),8G%P:75S
M5'9=*2@N*BDO(&]R(&QA<W0["FEF("@D,2!E<2`G22<I('L*<'5S:"!`861D
M7W1O7VEN8RP@)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@>PIE=F%L(")U<V4@
M)#(B.PI]"F5L<VEF("@D,2!E<2`G02<I('L*=6YS:&EF="!`<&%R7V%R9W,L
M("0R.PI]"F5L<VEF("@D,2!E<2`G3R<I('L*)&]U="`]("0R.PI]"F5L<VEF
M("@D,2!E<2`G8B<I('L*)&)U;F1L92`]("=S:71E)SL*?0IE;'-I9B`H)#$@
M97$@)T(G*2!["B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I9B`H)#$@97$@)W$G
M*2!["B1Q=6EE="`](#$["GT*96QS:68@*"0Q(&5Q("=,)RD@>PIO<&5N("1L
M;V=F:"P@(CX^(BP@)#(@;W(@9&EE('%Q6T-A;B=T(&]P96X@;&]G(&9I;&4@
M(B0R(CH@)"%=.PI]"F5L<VEF("@D,2!E<2`G5"<I('L*)&-A8VAE7VYA;64@
M/2`D,CL*?0IS:&EF="A`05)'5BD["FEF("AM>2`D8VUD(#T@)&1I<W1?8VUD
M>R0Q?2D@>PID96QE=&4@)$5.5GLG4$%27U1%35`G?3L*:6YI=%]I;F,H*3L*
M<F5Q=6ER92!005(Z.D1I<W0["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL
M97-S($!!4D=6.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6
M.PIE>&ET.PI]"GT*=6YS:&EF="!`24Y#+"!`861D7W1O7VEN8SL*?0I]"FEF
M("@D;W5T*2!["GL*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!!<F-H:79E
M.CI::7`["G)E<75I<F4@1&EG97-T.CI32$$["GT*;7D@)'!A<B`]('-H:69T
M*$!!4D=6*3L*;7D@)'II<#L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY
M("1F:"P@)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N)W0@9FEN9"!P87(@
M9FEL92`B)'!A<B(Z("0A73L*8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*)'II
M<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E861&<F]M1FEL94AA
M;F1L92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R
M(&1I92!Q<5M%<G)O<B!R96%D:6YG('II<"!A<F-H:79E("(D<&%R(ET["GT*
M;7D@)65N=B`](&1O('L*:68@*"1Z:7`@86YD(&UY("1M971A(#T@)'II<"T^
M8V]N=&5N=',H)TU%5$$N>6UL)RDI('L*)&UE=&$@/7X@<R\N*EYP87(Z)"\O
M;7,["B1M971A(#U^(',O7EQ3+BHO+VUS.PHD;65T82`]?B`O7B`@*%M>.ETK
M*3H@*"XK*20O;6<["GT*?3L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY
M("1P:"P@)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N)W0@<F5A9"!P87(@
M9FEL92`B)'!A<B(Z("0A73L*;7D@)&)U9CL*<F5A9"`D<&@L("1B=68L(#0[
M"F1I92!Q<5LB)'!A<B(@:7,@;F]T(&$@<&%R(&9I;&5=('5N;&5S<R`D8G5F
M(&5Q(")02UPP,#-<,#`T(CL*8VQO<V4@)'!H.PI]"D-R96%T95!A=&@H)&]U
M="D@.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`HD;W5T+`I)3SHZ1FEL93HZ
M3U]#4D5!5"@I('P@24\Z.D9I;&4Z.D]?5U)/3DQ9*"D@?"!)3SHZ1FEL93HZ
M3U]44E5.0R@I+`HP-S<W+`HI(&]R(&1I92!Q<5M#86XG="!C<F5A=&4@9FEL
M92`B)&]U="(Z("0A73L*)&9H+3YB:6YM;V1E*"D["G-E96L@7T9(+"`P+"`P
M.PIM>2`D;&]A9&5R.PII9B`H9&5F:6YE9"`D9&%T85]P;W,I('L*<F5A9"!?
M1D@L("1L;V%D97(L("1D871A7W!O<SL*?2!E;'-E('L*;&]C86P@)"\@/2!U
M;F1E9CL*)&QO861E<B`](#Q?1D@^.PI]"FEF("@A)$5.5GM005)?5D520D%4
M24U](&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@>PIR97%U:7)E
M(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP
M+3YA<'!L>2A<)&QO861E<BP@)#`I.PI]"F9O<F5A8V@@;7D@)&ME>2`H<V]R
M="!K97ES("5E;G8I('L*;7D@)'9A;"`]("1E;G9[)&ME>7T@;W(@;F5X=#L*
M)'9A;"`](&5V86P@)'9A;"!I9B`D=F%L(#U^("]>6R<B72\["FUY("1M86=I
M8R`](")?7T5.5E]005)?(B`N('5C*"1K97DI("X@(E]?(CL*;7D@)'-E="`]
M(")005)?(B`N('5C*"1K97DI("X@(CTD=F%L(CL*)&QO861E<B`]?B!S>R1M
M86=I8R@@*RE]>PHD;6%G:6,@+B`D<V5T("X@*"<@)R!X("AL96YG=&@H)#$I
M("T@;&5N9W1H*"1S970I*2D*?65G.PI]"B1F:"T^<')I;G0H)&QO861E<BD[
M"FEF("@D8G5N9&QE*2!["G)E<75I<F4@4$%2.CI(96%V>3L*4$%2.CI(96%V
M>3HZ7VEN:71?9'EN86QO861E<B@I.PII;FET7VEN8R@I.PIR97%U:7)E7VUO
M9'5L97,H*3L*;7D@0&EN8R`](&=R97`@>R`A+T)31%!!3B\@?0IG<F5P('L*
M*"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I9SHZ0V]N9FEG
M>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF:6=[<')I=FQI
M8F5X<'TI.PI]($!)3D,["G-\+RM\+WQG+"!S?"\D?'P@9F]R96%C:"!`:6YC
M.PIM>2`E9FEL97,["B1F:6QE<WLD7WTK*R!F;W(@0$1Y;F%,;V%D97(Z.F1L
M7W-H87)E9%]O8FIE8W1S+"!V86QU97,@)4E.0SL*;7D@)&QI8E]E>'0@/2`D
M0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T[("`@("`@("`@(R!86%@@;&EB7V5X
M="!V<R!D;&5X="`_"FUY("5W<FET=&5N.PIF;W)E86-H(&UY("1K97D@*'-O
M<G0@:V5Y<R`E9FEL97,I('L*;7D@*"1F:6QE+"`D;F%M92D["FEF("AD969I
M;F5D*&UY("1F8R`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&ME>7TI*2![
M"B@D9FEL92P@)&YA;64I(#T@*"1K97DL("1F8RD["GT*96QS92!["F9O<F5A
M8V@@;7D@)&1I<B`H0&EN8RD@>PII9B`H)&ME>2`]?B!M?%Y<421D:7)<12\H
M+BHI)'QI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL("0Q*3L*;&%S=#L*
M?0II9B`H)&ME>2`]?B!M?%XO;&]A9&5R+UM>+UTK+R@N*BDD?"D@>PII9B`H
M;7D@)')E9B`]("1-;V1U;&5#86-H97LD,7TI('L**"1F:6QE+"`D;F%M92D@
M/2`H)')E9BP@)#$I.PIL87-T.PI]"FEF("@M9B`B)&1I<B\D,2(I('L**"1F
M:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0["GT*?0I]"GT*
M;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M93L*;F5X="!I9B`D=W)I='1E;GLD
M;F%M97TK*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN
M7%$D;&EB7V5X=%Q%)"]I.PIO=71S*'-P<FEN=&8H<7%;4&%C:VEN9R!&24Q%
M("(E<R(N+BY=+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65](#H@)&9I;&4I
M*3L*;7D@)&-O;G1E;G0["FEF("AR968H)&9I;&4I*2!["B1C;VYT96YT(#T@
M)&9I;&4M/GMB=69].PI]"F5L<V4@>PIL;V-A;"`D+R`]('5N9&5F.PIO<&5N
M(&UY("1F:"P@)SPZ<F%W)RP@)&9I;&4@;W(@9&EE('%Q6T-A;B=T(')E860@
M(B1F:6QE(CH@)"%=.PHD8V]N=&5N="`](#PD9F@^.PIC;&]S92`D9F@["E!!
M4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1C;VYT96YT+"`B/&5M8F5D
M9&5D/B\D;F%M92(I"FEF("$D14Y6>U!!4E]615)"051)37T@86YD("1N86UE
M(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT97(Z.E!A=&-H0V]N
M=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M92D["GT*
M)&9H+3YP<FEN="@B1DE,12(L"G!A8VLH)TXG+"!L96YG=&@H)&YA;64I("L@
M.2DL"G-P<FEN=&8H(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#
M4D,S,B@D8V]N=&5N="DL("1N86UE*2P*<&%C:R@G3B<L(&QE;F=T:"@D8V]N
M=&5N="DI+`HD8V]N=&5N="D["F]U=',H<7%;5W)I='1E;B!A<R`B)&YA;64B
M72D["GT*?0HD>FEP+3YW<FET951O1FEL94AA;F1L92@D9F@I(&EF("1Z:7`[
M"B1C86-H95]N86UE(#T@<W5B<W1R("1C86-H95]N86UE+"`P+"`T,#L*:68@
M*"$D8V%C:&5?;F%M92!A;F0@;7D@)&UT:6UE(#T@*'-T870H)&]U="DI6SE=
M*2!["FUY("1C='@@/2!$:6=E<W0Z.E-(02T^;F5W*#$I.PIO<&5N(&UY("1F
M:"P@(CPZ<F%W(BP@)&]U=#L*)&-T>"T^861D9FEL92@D9F@I.PIC;&]S92`D
M9F@["B1C86-H95]N86UE(#T@)&-T>"T^:&5X9&EG97-T.PI]"B1C86-H95]N
M86UE("X](")<,"(@>"`H-#$@+2!L96YG=&@@)&-A8VAE7VYA;64I.PHD8V%C
M:&5?;F%M92`N/2`B0T%#2$4B.PHD9F@M/G!R:6YT*"1C86-H95]N86UE*3L*
M)&9H+3YP<FEN="AP86-K*"=.)RP@)&9H+3YT96QL("T@;&5N9W1H*"1L;V%D
M97(I*2D["B1F:"T^<')I;G0H)%!!4E]-04=)0RD["B1F:"T^8VQO<V4["F-H
M;6]D(#`W-34L("1O=70["F5X:70["GT*>PIL87-T('5N;&5S<R!D969I;F5D
M("1S=&%R=%]P;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q=6ER92!005(["E!!
M4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR97%U:7)E($9I;&4Z
M.D9I;F0["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1F:"`]($E/.CI&
M:6QE+3YN97<[("`@("`@("`@("`@("`@("`@("`@("`@("`@("`C($%R8VAI
M=F4Z.EII<"!O<&5R871E<R!O;B!A;B!)3SHZ2&%N9&QE"B1F:"T^9F1O<&5N
M*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I92!Q<5MF9&]P96XH*2!F86EL960Z
M("0A73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H+7,@7T9(*3L*;7D@
M)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E861&<F]M1FEL
M94AA;F1L92@D9F@L("1P<F]G;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/
M2R@I("D*;W(@9&EE('%Q6T5R<F]R(')E861I;F<@>FEP(&%R8VAI=F4@(B1P
M<F]G;F%M92)=.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@V-"`J(#$P
M,C0I.PIP=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PHD4$%2.CI,:6)#86-H
M97LD<')O9VYA;65](#T@)'II<#L*)'%U:65T(#T@(21%3E9[4$%27T1%0E5'
M?3L*;W5T<RAQ<5M<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB
M72D["FEF("AD969I;F5D("1%3E9[4$%27U1%35!]*2![(",@<VAO=6QD(&)E
M('-E="!A="!T:&ES('!O:6YT(0IF;W)E86-H(&UY("1M96UB97(@*"`D>FEP
M+3YM96UB97)S("D@>PIN97AT(&EF("1M96UB97(M/FES1&ER96-T;W)Y.PIM
M>2`D;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*;F5X="!U;FQE
M<W,@)&UE;6)E<E]N86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z)$-O;F9I9SHZ
M0V]N9FEG>W9E<G-I;VY]+RD_"B@_.B1#;VYF:6<Z.D-O;F9I9WMA<F-H;F%M
M97TO*3\**%M>+UTK*0HD"GUX.PIM>2`D97AT<F%C=%]N86UE(#T@)#$["FUY
M("1D97-T7VYA;64@/2!&:6QE.CI3<&5C+3YC871F:6QE*"1%3E9[4$%27U1%
M35!]+"`D97AT<F%C=%]N86UE*3L*:68@*"UF("1D97-T7VYA;64@)B8@+7,@
M7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S9613:7IE*"DI('L*;W5T<RAQ<5M3
M:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S:6YC92!I="!A;')E861Y(&5X:7-T
M<R!A="`B)&1E<W1?;F%M92)=*3L*?2!E;'-E('L*;W5T<RAQ<5M%>'1R86-T
M:6YG("(D;65M8F5R7VYA;64B('1O("(D9&5S=%]N86UE(ETI.PHD;65M8F5R
M+3YE>'1R86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D["F-H;6]D*#`U-34L
M("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["GT*?0I]"GT*=6YL97-S
M("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2!["F1I92`\/"`B+B(@=6YL
M97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;("U)9&ER(%T@
M6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!="B0P(%L@
M+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.5GM005)?4%)/1TY!
M345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'5BD["GT*<W5B($-R
M96%T95!A=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E<75I<F4@1FEL93HZ0F%S
M96YA;64["FUY("@D8F%S96YA;64L("1P871H+"`D97AT*2`]($9I;&4Z.D)A
M<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*<F5Q=6ER92!&
M:6QE.CI0871H.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I('5N;&5S<R@M
M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]"G-U8B!R97%U
M:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER92!$>6YA3&]A9&5R
M.PIR97%U:7)E(&EN=&5G97(["G)E<75I<F4@<W1R:6-T.PIR97%U:7)E('=A
M<FYI;F=S.PIR97%U:7)E('9A<G,["G)E<75I<F4@0V%R<#L*<F5Q=6ER92!#
M87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER92!%>'!O<G1E<CHZ
M2&5A=GD["G)E<75I<F4@17AP;W)T97(["G)E<75I<F4@1F-N=&P["G)E<75I
M<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C.PIR97%U:7)E(%A3
M3&]A9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)3SHZ2&%N9&QE.PIR
M97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($-O;7!R97-S.CI:;&EB.PIR97%U
M:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*<F5Q=6ER
M92!005(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!005(Z.D1I<W0[
M"G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PIR97%U:7)E(%!!4CHZ
M1FEL=&5R.CI0871C:$-O;G1E;G0["G)E<75I<F4@871T<FEB=71E<SL*979A
M;"![(')E<75I<F4@0W=D('T["F5V86P@>R!R97%U:7)E(%=I;C,R('T["F5V
M86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PIE=F%L('L@<F5Q=6ER92!!
M<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*979A;"![(')E<75I<F4@5&EE.CI(
M87-H.CI.86UE9$-A<'1U<F4@?3L*979A;"![(')E<75I<F4@4&5R;$E/.R!R
M97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T["F5V86P@>R!R97%U:7)E('5T9C@@
M?3L*?0IS=6(@7W-E=%]P87)?=&5M<"!["FEF("AD969I;F5D("1%3E9[4$%2
M7U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I('L*)'!A<E]T
M96UP(#T@)#$["G)E='5R;CL*?0IF;W)E86-H(&UY("1P871H("@**&UA<"`D
M14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2(%1%35!$25(@5$5-4"!4
M35`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP("X@*0HI('L*;F5X="!U;FQE<W,@
M9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD("UW("1P871H.PIM>2`D
M=7-E<FYA;64["FUY("1P=W5I9#L*979A;"![*"1P=W5I9"D@/2!G971P=W5I
M9"@D/BD@:68@9&5F:6YE9"`D/CM].PII9B`H(&1E9FEN960H)E=I;C,R.CI,
M;V=I;DYA;64I("D@>PHD=7-E<FYA;64@/2`F5VEN,S(Z.DQO9VEN3F%M93L*
M?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*)'5S97)N86UE(#T@)'!W=6ED
M.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D14Y6>U5315).04U%?2!\?"`D14Y6
M>U5315)]('Q\("=365-414TG.PI]"B1U<V5R;F%M92`]?B!S+UQ7+U\O9SL*
M;7D@)'-T;7!D:7(@/2`B)'!A=&@D0V]N9FEG>U]D96QI;7UP87(M(BYU;G!A
M8VLH(D@J(BP@)'5S97)N86UE*3L*;6MD:7(@)'-T;7!D:7(L(#`W-34["FEF
M("@A)$5.5GM005)?0TQ%04Y](&%N9"!M>2`D;71I;64@/2`H<W1A="@D<')O
M9VYA;64I*5LY72D@>PIO<&5N(&UY("1F:"P@(CPZ<F%W(BP@)'!R;V=N86UE
M(&]R(&1I92!Q<5M#86XG="!R96%D("(D<')O9VYA;64B.B`D(5T["G-E96L@
M)&9H+"`M,3@L(#(["FUY("1B=68["G)E860@)&9H+"`D8G5F+"`V.PII9B`H
M)&)U9B!E<2`B7#!#04-(12(I('L*<V5E:R`D9F@L("TU."P@,CL*<F5A9"`D
M9F@L("1B=68L(#0Q.PHD8G5F(#U^(',O7#`O+V<["B1S=&UP9&ER("X]("(D
M0V]N9FEG>U]D96QI;7UC86-H92TD8G5F(CL*?0IE;'-E('L*;7D@)&1I9V5S
M="`](&5V86P*>PIR97%U:7)E($1I9V5S=#HZ4TA!.PIM>2`D8W1X(#T@1&EG
M97-T.CI32$$M/FYE=R@Q*3L*;W!E;B!M>2`D9F@L("(\.G)A=R(L("1P<F]G
M;F%M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)'!R;V=N86UE(CH@)"%=.PHD
M8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E*"1F:"D["B1C='@M/FAE>&1I9V5S
M=#L*?2!\?"`D;71I;64["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC
M86-H92TD9&EG97-T(CL*?0IC;&]S92@D9F@I.PI]"F5L<V4@>PHD14Y6>U!!
M4E]#3$5!3GT@/2`Q.PHD<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]=&5M
M<"TD)"(["GT*)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*;6MD:7(@)'-T
M;7!D:7(L(#`W-34["FQA<W0["GT*)'!A<E]T96UP(#T@)#$@:68@)$5.5GM0
M05)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+SL*?0IS=6(@
M7W-A=F5?87,@>PIM>2`H)&YA;64L("1C;VYT96YT<RP@)&UO9&4I(#T@0%\[
M"FUY("1F=6QL;F%M92`]("(D<&%R7W1E;7`O)&YA;64B.PIU;FQE<W,@*"UE
M("1F=6QL;F%M92D@>PIM>2`D=&5M<&YA;64@/2`B)&9U;&QN86UE+B0D(CL*
M;W!E;B!M>2`D9F@L("<^.G)A=R<L("1T96UP;F%M92!O<B!D:64@<7%;0V%N
M)W0@=W)I=&4@(B1T96UP;F%M92(Z("0A73L*<')I;G0@)&9H("1C;VYT96YT
M<SL*8VQO<V4@)&9H.PIC:&UO9"`D;6]D92P@)'1E;7!N86UE(&EF(&1E9FEN
M960@)&UO9&4["G)E;F%M92@D=&5M<&YA;64L("1F=6QL;F%M92D@;W(@=6YL
M:6YK*"1T96UP;F%M92D["GT*<F5T=7)N("1F=6QL;F%M93L*?0IS=6(@7W-E
M=%]P<F]G;F%M92!["FEF("AD969I;F5D("1%3E9[4$%27U!23T=.04U%?2!A
M;F0@)$5.5GM005)?4%)/1TY!345](#U^("\H+BLI+RD@>PHD<')O9VYA;64@
M/2`D,3L*?0HD<')O9VYA;64@?'P]("0P.PII9B`H)$5.5GM005)?5$5-4'T@
M86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM005)?5$5-4'TI(#X](#`I('L*
M)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M
M92P@)$-O;F9I9WM?9&5L:6U]*2`K(#$I.PI]"FEF("@A)$5.5GM005)?4%)/
M1TY!345](&]R(&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`^
M/2`P*2!["FEF("AO<&5N(&UY("1F:"P@)SPG+"`D<')O9VYA;64I('L*<F5T
M=7)N(&EF("US("1F:#L*?0II9B`H+7,@(B1P<F]G;F%M921#;VYF:6=[7V5X
M97TB*2!["B1P<F]G;F%M92`N/2`D0V]N9FEG>U]E>&5].PIR971U<FX["GT*
M?0IF;W)E86-H(&UY("1D:7(@*'-P;&ET("]<421#;VYF:6=[<&%T:%]S97!]
M7$4O+"`D14Y6>U!!5$A]*2!["FYE>'0@:68@97AI<W1S("1%3E9[4$%27U1%
M35!](&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%35!].PHD9&ER(#U^(',O7%$D
M0V]N9FEG>U]D96QI;7U<120O+SL**"@D<')O9VYA;64@/2`B)&1I<B1#;VYF
M:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB*2P@;&%S="D*:68@
M+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5]
M(CL**"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M
M92(I+"!L87-T*0II9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M
M92(["GT*?0IS=6(@7V9I>%]P<F]G;F%M92!["B0P(#T@)'!R;V=N86UE('Q\
M/2`D14Y6>U!!4E]04D]'3D%-17T["FEF("AI;F1E>"@D<')O9VYA;64L("1#
M;VYF:6=[7V1E;&EM?2D@/"`P*2!["B1P<F]G;F%M92`]("(N)$-O;F9I9WM?
M9&5L:6U])'!R;V=N86UE(CL*?0IM>2`D<'=D(#T@*&1E9FEN960@)D-W9#HZ
M9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*.B`H*&1E9FEN960@)E=I;C,R.CI'
M971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PIC:&]M<"@D<'=D
M*3L*)'!R;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D0V]N9FEG>U]D96QI;7U<
M12DO)'!W9"1#;VYF:6=[7V1E;&EM?2\["B1%3E9[4$%27U!23T=.04U%?2`]
M("1P<F]G;F%M93L*?0IS=6(@7W!A<E]I;FET7V5N=B!["FEF("@@)$5.5GM0
M05)?24Y)5$E!3$E:141]*RL@/3T@,2`I('L*<F5T=7)N.PI](&5L<V4@>PHD
M14Y6>U!!4E])3DE424%,25I%1'T@/2`R.PI]"F9O<B`H<7<H(%-005=.140@
M5$5-4"!#3$5!3B!$14)51R!#04-(12!04D]'3D%-12`I("D@>PID96QE=&4@
M)$5.5GLG4$%27R<N)%]].PI]"F9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.
M($1%0E5'("\I('L*)$5.5GLG4$%27R<N)%]](#T@)$5.5GLG4$%27T=,3T)!
M3%\G+B1??2!I9B!E>&ES=',@)$5.5GLG4$%27T=,3T)!3%\G+B1??3L*?0IM
M>2`D<&%R7V-L96%N(#T@(E]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@
M("`@(CL*:68@*"1%3E9[4$%27U1%35!]*2!["F1E;&5T92`D14Y6>U!!4E]#
M3$5!3GT["GT*96QS:68@*"%E>&ES=',@)$5.5GM005)?1TQ/0D%,7T-,14%.
M?2D@>PIM>2`D=F%L=64@/2!S=6)S='(H)'!A<E]C;&5A;BP@,3(@*R!L96YG
M=&@H(D-,14%.(BDI.PHD14Y6>U!!4E]#3$5!3GT@/2`D,2!I9B`D=F%L=64@
M/7X@+UY005)?0TQ%04X]*%Q3*RDO.PI]"GT*<W5B(&]U=',@>PIR971U<FX@
M:68@)'%U:65T.PII9B`H)&QO9V9H*2!["G!R:6YT("1L;V=F:"`B0%]<;B([
M"GT*96QS92!["G!R:6YT(")`7UQN(CL*?0I]"G-U8B!I;FET7VEN8R!["G)E
M<75I<F4@0V]N9FEG.PIP=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P("1#
M;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`IA<F-H;&EB97AP('!R:79L:6)E>'`@
M<VET96%R8VAE>'`@<VET96QI8F5X<`IV96YD;W)A<F-H97AP('9E;F1O<FQI
M8F5X<`HI.PI]"G!A8VMA9V4@;6%I;CL*<F5Q=6ER92!005(["G5N<VAI9G0@
M0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R="A`<&%R7V%R9W,I
M.PID:64@<7%;<&%R+G!L.B!#86XG="!O<&5N('!E<FP@<V-R:7!T("(D<')O
M9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&Y="G5N;&5S<R`M
M92`D<')O9VYA;64["F1O("1P<F]G;F%M93L*0T]213HZ97AI="@D,2D@:68@
M*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`.PI]
M.PHD.CI?7T524D]2(#T@)$`@:68@)$`["GT*0T]213HZ97AI="@D,2D@:68@
M*"0Z.E]?15)23U(@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)#HZ
M7U]%4E)/4B!I9B`D.CI?7T524D]2.PHQ.PI?7T5.1%]?"@```1L#.^@````<
M````_)+__P`!``!<D___)`$``.23__],`0``E)7__[0!``!\EO__X`$``"27
M__\0`@``A)C__T0"``"\FO__?`(``$R;__^H`@``M)O__^`"```LG/__"`,`
M`#2<__\<`P``M)[__U0#``#<GO__:`,``#"@__^X`P``8*+__^@#```(H___
M$`0``"BC__\P!```'*3__V0$``#4J___G`0``)BN___0!````*___S`%```(
MN___:`4``&B[__^,!0``5+S__[@%``#,O?__A`$``%2^__]P`0``J+[__P`%
M```0``````````%Z4@`"?`X!&PP-`"`````8````])'__V``````0@T,2(0&
MA06+!(T#C@)*#`L$`"0````\````,)+__X@`````0@T,2H0(A0>&!H<%BP2-
M`XX"1@P+!``@````9````)"2__^P`0```$(-#$2'!8L$C0..`D(,"P0````0
M````B````-R\__]4`````````"P```"<````0+S__X@`````0@T,1(0&A06+
M!(T#C@),#`L$8@P-&$+.S<O%Q`X$`"@```#,````V)/__^@`````0@T,1(0*
MA0F&"(<'B`:)!8L$C0..`D0,"P0`+````/@```"4E/__J`````!"#0Q"A`B%
M!X8&AP6+!(T#C@)"#`L$`D0*#`T@0@L`,````"@!```,E?__8`$```!"#0Q"
MA`N%"H8)APB(!XD&B@6+!(T#C@)"#`L$8@H,#2Q""S0```!<`0``.);__S@"
M````0@T,0H0+A0J&"8<(B`>)!HH%BP2-`XX"0@P+!`*8"@P-+$(+````*```
M`)0!```XF/__D`````!"#0Q"A`:%!8L$C0..`D(,"P1N"@P-&$(+```T````
MP`$``)R8__]H`````$(-#$B$"(4'A@:'!8L$C0..`D(,"P1:#`T@0L[-R\?&
MQ<0.!````"0```#X`0``S)C__W@`````0@T,1(0&A06+!(T#C@)$#`L$9@P-
M&``0````(`(``!R9__\(`````````#0````T`@``$)G__X`"````0@T,0H0+
MA0J&"8<(B`>)!HH%BP2-`XX"1`P+!`)""@P-+$(+````$````&P"``!8F___
M*`````````!,````@`(``&R;__]4`0```$(-#$*$!H4%BP2-`XX"1`P+!'@*
M#`T80L[-R\7$#@1""T8*#`T80L[-R\7$#@1""P)0#`T80L[-R\7$#@0``"P`
M``#0`@``<)S__S`"````0@T,0H0'A0:&!8L$C0..`D(,"P0"L`H,#1Q""P``
M`"0``````P``<)[__Z@`````0@T,0H0%BP2-`XX"0@P+!&(*#`T40@L<````
M*`,``/">__\@`````$(-#$*+!(T#C@)"#`L$`#````!(`P``\)[___0`````
M0@T,0H0)A0B&!X<&B`6+!(T#C@)"#`L$`F0*#`TD0@L````T````?`,``+"?
M__^X!P```$(-#$*$"X4*A@F'"(@'B0:*!8L$C0..`D0,"P0#9@$*#`TL0@L`
M`#````"T`P``,*?__\0"````0@T,0H0)A0B&!X<&B`6+!(T#C@)"#`L$`MH*
M#`TD0@L````L````Z`,``,"I__]H`````$(-#$*$!H4%BP2-`XX"0@P+!&@,
M#1A"SLW+Q<0.!``L````&`0``*"Y__^``@```$(-#$*$"(4'A@:'!8L$C0..
M`D(,"P0"T`H,#2!""P`T````2`0``,BI__\(#````$(-#$*$"X4*A@F'"(@'
MB0:*!8L$C0..`D(,"P0#[@4*#`TL0@L``"````"`!```F+7__V``````0@T,
M1(0&A06+!(T#C@)"#`L$`"@```"D!```U+7__^P`````0@T,1(0*A0F&"(<'
MB`:)!8L$C0..`EH,"P0`/````-`$``"4MO__>`$```!"#0Q"A`J%"88(AP>(
M!HD%BP2-`XX"5@P+!`*6"@P-*$+.S<O)R,?&Q<0.!$(+``````!`00``N$``
M```````!`````0````$```"B`@```0```*P"```!````N@(```$```#@`@``
M#P```'H$```9````Z(@!`!L````$````&@```.R(`0`<````!`````0```!T
M`0``!0```/@*```&````F`0```H```"_!```"P```!`````5``````````,`
M``#DB0$``@```/@!```4````$0```!<```#8$```$0```+@/```2````(`$`
M`!,````(````^___;P````CZ__]O&0``````````````````````````````
M``````````````````````````#TB`$```````````#0$@``T!(``-`2``#0
M$@``T!(``-`2``#0$@``T!(``-`2``#0$@``T!(``-`2``#0$@``T!(``-`2
M``#0$@``T!(``-`2``#0$@``T!(``-`2``#0$@``T!(``-`2``#0$@``T!(`
M`-`2``#0$@``T!(``-`2``#0$@``T!(``-`2``#0$@``T!(``-`2``#0$@``
MT!(``-`2``#0$@``T!(``-`2``#0$@``T!(``-`2``#0$@``T!(``-`2``#0
M$@``T!(``-`2``#0$@``T!(``-`2``#0$@``T!(``-`2``#0$@``T!(``-`2
M``#0$@``T!(``-`2``#PB`$``````,@0````````Z(@!````````````````
M``"0`0#($````````.R(`0"`BP$`````````````````](@!``````#$BP$`
M`````$2+`0#`+@``P(L!`$B+`0#_____9$<``%A$````````5$4``%A%``!8
M1P``H$0``&!'````````1$<``$Q'````````;$<``$=#0SH@*$YE=$)31"!N
M8C0@,C`R,#`X,3`I(#<N-2XP`$=#0SH@*$YE=$)31"!N8C,@,C`Q.3`S,3DI
M(#<N-"XP`"1.971"4T0Z(&-R=#`N4RQV(#$N-"`R,#$X+S$Q+S(V(#$W.C,W
M.C0T(&IO97)G($5X<"`D`"1.971"4T0Z(&-R=#`M8V]M;6]N+F,L=B`Q+C(S
M(#(P,3@O,3(O,C@@,C`Z,3(Z,S4@8VAR:7-T;W,@17AP("0`)$YE=$)31#H@
M8W)T:2Y3+'8@,2XQ(#(P,3(O,#@O,3,@,#(Z-#DZ,#0@;6%T="!%>'`@)``D
M3F5T0E-$.B!C<G1B96=I;BYC+'8@,2XQ-R`R,#$X+S$R+S(X(#$X.C$W.C$Q
M(&-H<FES=&]S($5X<"`D`"1.971"4T0Z(&-R=&5N9"Y3+'8@,2XR(#(P,3,O
M,3(O,C`@,34Z,S4Z-#@@:F]E<F<@17AP("0`\<\"``````````````````@`
M```(````"`````@````;`````0``````````*BHJ($YO($QA8F5L(%!R;W9I
M9&5D("HJ*@``\<\"``````````````````@````(````"`````@````;````
M`0``````````*BHJ($YO($QA8F5L(%!R;W9I9&5D("HJ*@!!*````&%E86)I
M``$>````!4%233E%``8$"`$)`1($%`$5`1<#&`$:`@`N<VAS=')T86(`+FEN
M=&5R<``N;F]T92YN971B<V0N:61E;G0`+FYO=&4N;F5T8G-D+G!A>``N;F]T
M92YN971B<V0N;6%R8V@`+FAA<V@`+F1Y;G-Y;0`N9'EN<W1R`"YR96PN9'EN
M`"YR96PN<&QT`"YT97AT`"YR;V1A=&$`+F5H7V9R86UE7VAD<@`N96A?9G)A
M;64`+FEN:71?87)R87D`+F9I;FE?87)R87D`+FIC<@`N9'EN86UI8P`N9V]T
M`"YD871A`"YB<W,`+F-O;6UE;G0`+E-53E=?8W1F`"Y!4DTN871T<FEB=71E
M<P``````````````````````````````````````````````````````````
M"P````$````"````%`$``!0!```7```````````````!`````````!,````'
M`````@```"P!```L`0``&```````````````!``````````F````!P````(`
M``!$`0``1`$``!0```````````````0`````````-P````<````"````6`$`
M`%@!```<```````````````$`````````$H````%`````@```'0!``!T`0``
M)`,```8`````````!`````0```!0````"P````(```"8!```F`0``&`&```'
M`````P````0````0````6`````,````"````^`H``/@*``"_!```````````
M```!`````````&`````)`````@```+@/``"X#P``(`$```8`````````!```
M``@```!I````"0```$(```#8$```V!```/@!```&````$P````0````(````
M;0````$````&````T!(``-`2```(`P`````````````$````!````'(````!
M````!@```-@5``#8%0``/"X`````````````!`````````!X`````0````(`
M```41```%$0``-@^``````````````0`````````@`````$````"````[((`
M`.R"``#L```````````````$`````````(X````!`````@```-B#``#8@P``
M$`4`````````````!`````````"8````#@````,```#HB`$`Z(@```0`````
M``````````0````$````I`````\````#````[(@!`.R(```$````````````
M```$````!````+`````!`````P```/"(`0#PB```!```````````````!```
M``````"U````!@````,```#TB`$`](@``/`````'``````````0````(````
MO@````$````#````Y(D!`.2)``!@`0`````````````$````!````,,````!
M`````P```$2+`0!$BP``0```````````````!`````````#)````"`````,`
M``#`BP$`A(L``$0$`````````````$``````````S@````$````P````````
M`(2+``!"```````````````!`````0```!\````!``````````````#&BP``
M(@$``````````````0````````#7`````0``````````````Z(P``(\`````
M``````````0`````````X0````,``'```````````'>-```I````````````
M```!``````````$````#``````````````"@C0``\0```````````````0``
%````````
